"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isAccessible = exports.accessible = exports.X_OK = exports.W_OK = exports.R_OK = exports.F_OK = void 0;
// as we are a low-level compatibility layer, do what is compatible with tree shaking
// [node >= 14] import { access } from 'node:fs/promises' // compatible with tree-shaking but breaks older versions
// [node < 14] import { promises } from 'fs'; const { access } = promises // breaks tree-shaking
const fs_1 = require("fs");
/** Is the path visible to the calling process? */
exports.F_OK = 0; // constants?.F_OK
/** Is the path readable to the calling process? */
exports.R_OK = 4; // constants?.R_OK
/** Is the path writable to the calling process? */
exports.W_OK = 2; // constants?.W_OK
/** Is the path executable to the calling process? */
exports.X_OK = 1; // constants?.X_OK
/** Returns a Promise that rejects with an error if the path is not accessible. */
function accessible(path, mode = exports.F_OK) {
    if (Array.isArray(path)) {
        return Promise.all(path.map((i) => accessible(i, mode))).then(() => { });
    }
    return new Promise((resolve, reject) => {
        (0, fs_1.access)(path, mode, (err) => {
            if (err)
                reject(err);
            else
                resolve();
        });
    });
}
exports.accessible = accessible;
exports.default = accessible;
function isAccessible(path, mode = exports.F_OK) {
    if (Array.isArray(path)) {
        return Promise.all(path.map((i) => isAccessible(i, mode)));
    }
    return accessible(path, mode)
        .then(() => true)
        .catch(() => false);
}
exports.isAccessible = isAccessible;
